@@ -43,6 +43,7 @@ std::string getVecKeyword(GpuLanguage lang)
         case GPU_LANGUAGE_GLSL_1_2:
         case GPU_LANGUAGE_GLSL_1_3:
         case GPU_LANGUAGE_GLSL_4_0:
+        case GPU_LANGUAGE_GLSL_VK_4_6:
         case GPU_LANGUAGE_GLSL_ES_1_0:
         case GPU_LANGUAGE_GLSL_ES_3_0:
         {
@@ -80,7 +81,9 @@ void getTexDecl(GpuLanguage lang,
                 const std::string & textureName, 
                 const std::string & samplerName,
                 std::string & textureDecl, 
-                std::string & samplerDecl)
+                std::string & samplerDecl,
+                unsigned descriptorSetIndex,
+                unsigned textureIndex)
 {
     switch (lang)
     {
@@ -98,6 +101,16 @@ void getTexDecl(GpuLanguage lang,
             samplerDecl = kw.str();
             break;
         }
+        case GPU_LANGUAGE_GLSL_VK_4_6:
+        {
+            textureDecl = "";
+
+            std::ostringstream kw;
+            kw << "layout(set=" << descriptorSetIndex << ", binding = " << textureIndex << ") ";
+            kw << "uniform sampler" << N << "D " << samplerName << "; ";
+            samplerDecl = kw.str();
+            break;
+        }
         case GPU_LANGUAGE_HLSL_SM_5_0:
         {
             std::ostringstream t;
@@ -172,6 +185,7 @@ std::string getTexSample(GpuLanguage lang,
             break;
         }
         case GPU_LANGUAGE_GLSL_4_0:
+        case GPU_LANGUAGE_GLSL_VK_4_6:
         {
             kw << "texture(" << samplerName << ", " << coords << ")";
             break;
@@ -337,6 +351,7 @@ std::string GpuShaderText::constKeyword() const
         case GPU_LANGUAGE_GLSL_1_2:
         case GPU_LANGUAGE_GLSL_1_3:
         case GPU_LANGUAGE_GLSL_4_0:
+        case GPU_LANGUAGE_GLSL_VK_4_6:
         case GPU_LANGUAGE_GLSL_ES_1_0:
         case GPU_LANGUAGE_GLSL_ES_3_0:
         case GPU_LANGUAGE_MSL_2_0:
@@ -531,6 +546,7 @@ void GpuShaderText::declareFloatArrayConst(const std::string & name, int size, c
         case GPU_LANGUAGE_GLSL_1_2:
         case GPU_LANGUAGE_GLSL_1_3:
         case GPU_LANGUAGE_GLSL_4_0:
+        case GPU_LANGUAGE_GLSL_VK_4_6:
         case GPU_LANGUAGE_GLSL_ES_1_0:
         case GPU_LANGUAGE_GLSL_ES_3_0:
         {
@@ -593,6 +609,7 @@ void GpuShaderText::declareIntArrayConst(const std::string & name, int size, con
         case GPU_LANGUAGE_GLSL_1_2:
         case GPU_LANGUAGE_GLSL_1_3:
         case GPU_LANGUAGE_GLSL_4_0:
+        case GPU_LANGUAGE_GLSL_VK_4_6:
         case GPU_LANGUAGE_GLSL_ES_1_0:
         case GPU_LANGUAGE_GLSL_ES_3_0:
         {
@@ -826,10 +843,13 @@ std::string GpuShaderText::getSamplerName(const std::string& textureName)
     return textureName + "Sampler";
 }
 
-void GpuShaderText::declareTex1D(const std::string & textureName)
+void GpuShaderText::declareTex1D(const std::string & textureName,
+                                 unsigned descriptorSetIndex, 
+                                 unsigned textureIndex, unsigned textureBindingStart)
 {
     std::string textureDecl, samplerDecl;
-    getTexDecl<1>(m_lang, textureName, getSamplerName(textureName), textureDecl, samplerDecl);
+    getTexDecl<1>(m_lang, textureName, getSamplerName(textureName), textureDecl, samplerDecl,
+                  descriptorSetIndex, textureIndex + textureBindingStart);
 
     if (!textureDecl.empty())
     {
@@ -842,10 +862,13 @@ void GpuShaderText::declareTex1D(const std::string & textureName)
     }
 }
 
-void GpuShaderText::declareTex2D(const std::string & textureName)
+void GpuShaderText::declareTex2D(const std::string & textureName,
+                                 unsigned descriptorSetIndex,
+                                 unsigned textureIndex, unsigned textureBindingStart)
 {
     std::string textureDecl, samplerDecl;
-    getTexDecl<2>(m_lang, textureName, getSamplerName(textureName), textureDecl, samplerDecl);
+    getTexDecl<2>(m_lang, textureName, getSamplerName(textureName), textureDecl, samplerDecl,
+                  descriptorSetIndex, textureIndex + textureBindingStart);
 
     if (!textureDecl.empty())
     {
@@ -858,10 +881,13 @@ void GpuShaderText::declareTex2D(const std::string & textureName)
     }
 }
 
-void GpuShaderText::declareTex3D(const std::string& textureName)
+void GpuShaderText::declareTex3D(const std::string& textureName,
+                                 unsigned descriptorSetIndex,
+                                 unsigned textureIndex, unsigned textureBindingStart)
 {
     std::string textureDecl, samplerDecl;
-    getTexDecl<3>(m_lang, textureName, getSamplerName(textureName), textureDecl, samplerDecl);
+    getTexDecl<3>(m_lang, textureName, getSamplerName(textureName), textureDecl, samplerDecl,
+                  descriptorSetIndex, textureIndex + textureBindingStart);
 
     if (!textureDecl.empty())
     {
@@ -895,27 +921,58 @@ std::string GpuShaderText::sampleTex3D(const std::string& textureName,
 
 void GpuShaderText::declareUniformFloat(const std::string & uniformName)
 {
-    newLine() << (m_lang == GPU_LANGUAGE_MSL_2_0 ? "" : "uniform ") << floatKeyword() << " " << uniformName << ";";
+    std::string uniformDeclString("uniform ");
+    if (m_lang == GPU_LANGUAGE_MSL_2_0 || m_lang == GPU_LANGUAGE_GLSL_VK_4_6)
+    {
+        uniformDeclString = "";
+    }
+    newLine() << uniformDeclString << floatKeyword() << " " << uniformName << ";";
 }
 
 void GpuShaderText::declareUniformBool(const std::string & uniformName)
 {
-    newLine() << (m_lang == GPU_LANGUAGE_MSL_2_0 ? "" : "uniform ") << "bool " << uniformName << ";";
+    std::string uniformDeclString("uniform ");
+    std::string boolKeyword("bool");
+    if (m_lang == GPU_LANGUAGE_MSL_2_0)
+    {
+        uniformDeclString = "";
+    }
+    else if (m_lang == GPU_LANGUAGE_GLSL_VK_4_6)
+    {
+        uniformDeclString = "";
+        boolKeyword = "int";
+    }
+    newLine() << uniformDeclString << boolKeyword << " " << uniformName << ";";
 }
 
 void GpuShaderText::declareUniformFloat3(const std::string & uniformName)
 {
-    newLine() << (m_lang == GPU_LANGUAGE_MSL_2_0 ? "" : "uniform ") << float3Keyword() << " " << uniformName << ";";
+    std::string uniformDeclString("uniform ");
+    if (m_lang == GPU_LANGUAGE_MSL_2_0 || m_lang == GPU_LANGUAGE_GLSL_VK_4_6)
+    {
+        uniformDeclString = "";
+    }
+    newLine() << uniformDeclString << float3Keyword() << " " << uniformName << ";";
 }
 
 void GpuShaderText::declareUniformArrayFloat(const std::string & uniformName, unsigned int size)
 {
-    newLine() << (m_lang == GPU_LANGUAGE_MSL_2_0 ? "" : "uniform ") << floatKeyword() << " " << uniformName << "[" << size << "];";
+    std::string uniformDeclString("uniform ");
+    if (m_lang == GPU_LANGUAGE_MSL_2_0 || m_lang == GPU_LANGUAGE_GLSL_VK_4_6)
+    {
+        uniformDeclString = "";
+    }
+    newLine() << uniformDeclString << floatKeyword() << " " << uniformName << "[" << size << "];";
 }
 
 void GpuShaderText::declareUniformArrayInt(const std::string & uniformName, unsigned int size)
 {
-    newLine() << (m_lang == GPU_LANGUAGE_MSL_2_0 ? "" : "uniform ") << intKeyword() << " " << uniformName << "[" << size << "];";
+    std::string uniformDeclString("uniform ");
+    if (m_lang == GPU_LANGUAGE_MSL_2_0 || m_lang == GPU_LANGUAGE_GLSL_VK_4_6)
+    {
+        uniformDeclString = "";
+    }
+    newLine() << uniformDeclString << intKeyword() << " " << uniformName << "[" << size << "];";
 }
 
 // Keep the method private as only float & double types are expected
@@ -933,6 +990,7 @@ std::string matrix3Mul(const T * m3x3, const std::string & vecName, GpuLanguage
         case GPU_LANGUAGE_GLSL_1_2:
         case GPU_LANGUAGE_GLSL_1_3:
         case GPU_LANGUAGE_GLSL_4_0:
+        case GPU_LANGUAGE_GLSL_VK_4_6:
         case GPU_LANGUAGE_GLSL_ES_1_0:
         case GPU_LANGUAGE_GLSL_ES_3_0:
         {
@@ -999,6 +1057,7 @@ std::string matrix4Mul(const T * m4x4, const std::string & vecName, GpuLanguage
         case GPU_LANGUAGE_GLSL_1_2:
         case GPU_LANGUAGE_GLSL_1_3:
         case GPU_LANGUAGE_GLSL_4_0:
+        case GPU_LANGUAGE_GLSL_VK_4_6:
         case GPU_LANGUAGE_GLSL_ES_1_0:
         case GPU_LANGUAGE_GLSL_ES_3_0:
         {
@@ -1061,6 +1120,7 @@ std::string GpuShaderText::lerp(const std::string & x,
         case GPU_LANGUAGE_GLSL_1_2:
         case GPU_LANGUAGE_GLSL_1_3:
         case GPU_LANGUAGE_GLSL_4_0:
+        case GPU_LANGUAGE_GLSL_VK_4_6:
         case GPU_LANGUAGE_GLSL_ES_1_0:
         case GPU_LANGUAGE_GLSL_ES_3_0:
         case GPU_LANGUAGE_MSL_2_0:
@@ -1092,6 +1152,7 @@ std::string GpuShaderText::float3GreaterThan(const std::string & a,
         case GPU_LANGUAGE_GLSL_1_2:
         case GPU_LANGUAGE_GLSL_1_3:
         case GPU_LANGUAGE_GLSL_4_0:
+        case GPU_LANGUAGE_GLSL_VK_4_6:
         case GPU_LANGUAGE_GLSL_ES_1_0:
         case GPU_LANGUAGE_GLSL_ES_3_0:
         case GPU_LANGUAGE_CG:
@@ -1127,6 +1188,7 @@ std::string GpuShaderText::float4GreaterThan(const std::string & a,
         case GPU_LANGUAGE_GLSL_1_2:
         case GPU_LANGUAGE_GLSL_1_3:
         case GPU_LANGUAGE_GLSL_4_0:
+        case GPU_LANGUAGE_GLSL_VK_4_6:
         case GPU_LANGUAGE_GLSL_ES_1_0:
         case GPU_LANGUAGE_GLSL_ES_3_0:
         case GPU_LANGUAGE_CG:
@@ -1171,6 +1233,7 @@ std::string GpuShaderText::float3GreaterThanEqual(const std::string& a,
     case GPU_LANGUAGE_GLSL_1_2:
     case GPU_LANGUAGE_GLSL_1_3:
     case GPU_LANGUAGE_GLSL_4_0:
+    case GPU_LANGUAGE_GLSL_VK_4_6:
     case GPU_LANGUAGE_GLSL_ES_1_0:
     case GPU_LANGUAGE_GLSL_ES_3_0:
     case GPU_LANGUAGE_CG:
@@ -1206,6 +1269,7 @@ std::string GpuShaderText::float4GreaterThanEqual(const std::string& a,
     case GPU_LANGUAGE_GLSL_1_2:
     case GPU_LANGUAGE_GLSL_1_3:
     case GPU_LANGUAGE_GLSL_4_0:
+    case GPU_LANGUAGE_GLSL_VK_4_6:
     case GPU_LANGUAGE_GLSL_ES_1_0:
     case GPU_LANGUAGE_GLSL_ES_3_0:
     case GPU_LANGUAGE_CG:
@@ -1251,6 +1315,7 @@ std::string GpuShaderText::atan2(const std::string & y,
         case GPU_LANGUAGE_GLSL_1_2:
         case GPU_LANGUAGE_GLSL_1_3:
         case GPU_LANGUAGE_GLSL_4_0:
+        case GPU_LANGUAGE_GLSL_VK_4_6:
         case GPU_LANGUAGE_GLSL_ES_1_0:
         case GPU_LANGUAGE_GLSL_ES_3_0:
         {
@@ -1290,6 +1355,7 @@ std::string GpuShaderText::sign(const std::string & v) const
         case GPU_LANGUAGE_GLSL_1_2:
         case GPU_LANGUAGE_GLSL_1_3:
         case GPU_LANGUAGE_GLSL_4_0:
+        case GPU_LANGUAGE_GLSL_VK_4_6:
         case GPU_LANGUAGE_GLSL_ES_1_0:
         case GPU_LANGUAGE_GLSL_ES_3_0:
         case GPU_LANGUAGE_HLSL_SM_5_0:
@@ -1312,6 +1378,15 @@ std::string GpuShaderText::sign(const std::string & v) const
     return kw.str();
 }
 
+std::string GpuShaderText::castToBool(const std::string& v) const
+{
+    if (m_lang == GPU_LANGUAGE_GLSL_VK_4_6)
+    {
+        return "bool(" + v + ")";
+    }
+    return v;
+}
+
 
 std::string BuildResourceName(GpuShaderCreatorRcPtr & shaderCreator, const std::string & prefix,
                               const std::string & base)
@@ -1353,6 +1428,25 @@ void AddLinToLogShader(GpuShaderCreatorRcPtr & shaderCreator, GpuShaderText & st
     st.newLine() << "}";
 }
 
+void AddLinToLogShaderChannelBlue(GpuShaderCreatorRcPtr & shaderCreator, GpuShaderText & st)
+{
+    const std::string pix(shaderCreator->getPixelName());
+
+    st.newLine() << "{";   // establish scope so local variable names won't conflict
+    st.indent();
+    st.newLine() << st.floatKeywordConst() << " xbrk = 0.0041318374739483946;";
+    st.newLine() << st.floatKeywordConst() << " shift = -0.000157849851665374;";
+    st.newLine() << st.floatKeywordConst() << " m = 1. / (0.18 + shift);";
+    st.newLine() << st.floatKeywordConst() << " base2 = 1.4426950408889634;";  // 1/log(2)
+    st.newLine() << st.floatKeywordConst() << " gain = 363.034608563;";
+    st.newLine() << st.floatKeywordConst() << " offs = -7.;";
+    st.newLine() << st.float3Decl("ylin") << " = " << pix << ".rgb * gain + offs;";
+    st.newLine() << st.float3Decl("ylog") << " = base2 * log( ( " << pix << ".rgb + shift ) * m );";
+    st.newLine() << pix << ".rgb.b = (" << pix << ".rgb.b < xbrk) ? ylin.z : ylog.z;";
+    st.dedent();
+    st.newLine() << "}";
+}
+
 void AddLogToLinShader(GpuShaderCreatorRcPtr & shaderCreator, GpuShaderText & st)
 {
     const std::string pix(shaderCreator->getPixelName());
@@ -1373,4 +1467,22 @@ void AddLogToLinShader(GpuShaderCreatorRcPtr & shaderCreator, GpuShaderText & st
     st.newLine() << "}";
 }
 
+void AddLogToLinShaderChannelBlue(GpuShaderCreatorRcPtr & shaderCreator, GpuShaderText & st)
+{
+    const std::string pix(shaderCreator->getPixelName());
+
+    st.newLine() << "{";   // establish scope so local variable names won't conflict
+    st.indent();
+    st.newLine() << st.floatKeywordConst() << " ybrk = -5.5;";
+    st.newLine() << st.floatKeywordConst() << " shift = -0.000157849851665374;";
+    st.newLine() << st.floatKeywordConst() << " gain = 363.034608563;";
+    st.newLine() << st.floatKeywordConst() << " offs = -7.;";
+    st.newLine() << st.float3Decl("xlin") << " = (" << pix << ".rgb - offs) / gain;";
+    st.newLine() << st.float3Decl("xlog") << " = pow( " << st.float3Const(2.0f)
+                                          <<          ", " << pix << ".rgb ) * (0.18 + shift) - shift;";
+    st.newLine() << pix << ".rgb.b = (" << pix << ".rgb.b < ybrk) ? xlin.z : xlog.z;";
+    st.dedent();
+    st.newLine() << "}";
+}
+
 } // namespace OCIO_NAMESPACE
