@@ -434,7 +434,11 @@ OCIO_ADD_GPU_TEST(FixedFunction, style_aces2_output_transform_inv)
 
 OCIO_ADD_GPU_TEST(FixedFunction, style_aces2_output_transform_invfwd)
 {
-     const double data_inv[9] = {
+    // Test that there are no shader resource (textures, functions, etc) conflicts between
+    // the 2 different inverse and forward transforms.  This is not a round-trip test,
+    // it tests that the forward and inverse may exist in the same shader with no issue.
+
+    const double data_inv[9] = {
         // Peak luminance
         100.f,
         // REC709 gamut
@@ -458,11 +462,320 @@ OCIO_ADD_GPU_TEST(FixedFunction, style_aces2_output_transform_invfwd)
     grp->appendTransform(func_inv);
     grp->appendTransform(func_fwd);
 
+    test.setTestNaN(false); // TODO: Partially running the output transform without the clamp so do not test Nan or Inf values
+    test.setTestInfinity(false);
+
     test.setProcessor(grp);
 
+    // This is not expected to be an identity, but it should be the same between CPU & GPU.
     test.setErrorThreshold(7e-4f);
 }
 
+namespace
+{
+
+OCIO::GroupTransformRcPtr BuildDisplayViewTransform(const char * display_style, 
+                                                    const char * view_style, 
+                                                    bool doRoundTrip)
+{
+    // Built-in transform for the display.
+    OCIO::BuiltinTransformRcPtr display_builtin = OCIO::BuiltinTransform::Create();
+    display_builtin->setStyle(display_style);
+    display_builtin->validate();
+    auto display_builtin_inv = display_builtin->createEditableCopy();
+    display_builtin_inv->setDirection(OCIO::TRANSFORM_DIR_INVERSE);
+
+    // Built-in transform for the view.
+    OCIO::BuiltinTransformRcPtr view_builtin = OCIO::BuiltinTransform::Create();
+    view_builtin->setStyle(view_style);
+    view_builtin->validate();
+    auto view_builtin_inv = view_builtin->createEditableCopy();
+    view_builtin_inv->setDirection(OCIO::TRANSFORM_DIR_INVERSE);
+
+    // Assemble inverse and forward transform into a group transform that goes from
+    // display code values to ACES2065-1 and (optionally) back to display code values.
+    OCIO::GroupTransformRcPtr group = OCIO::GroupTransform::Create();
+    group->appendTransform(display_builtin_inv);
+    group->appendTransform(view_builtin_inv);
+    if (doRoundTrip)
+    {
+        group->appendTransform(view_builtin);
+        group->appendTransform(display_builtin);
+    }
+    return group;
+}
+
+void GenerateIdentityLut3D(OCIOGPUTest::CustomValues & values, int edgeLen, float scale)
+{
+    const int numChannels = 4;
+    int num_samples = edgeLen * edgeLen * edgeLen;
+    std::vector<float> img(num_samples * numChannels, 0.f);
+
+    float c = 1.0f / ((float)edgeLen - 1.0f);
+    for (int i = 0; i < edgeLen*edgeLen*edgeLen; i++)
+    {
+        img[numChannels*i + 0] = scale * (float)(i%edgeLen) * c;
+        img[numChannels*i + 1] = scale * (float)((i / edgeLen) % edgeLen) * c;
+        img[numChannels*i + 2] = scale * (float)((i / edgeLen / edgeLen) % edgeLen) * c;
+    }
+    values.m_inputValues = img;
+}
+
+} // anon.
+
+// NOTE: Some of the following tests compare the round-trip from display code value to ACES2065-1
+// and back to display code value. The round-trip is not perfect (see BuiltinTransform_tests.cpp)
+// but the tests here simply check if the CPU and GPU are giving the same result.
+
+OCIO_ADD_GPU_TEST(FixedFunction, style_aces2_rec709_rndtrip)
+{
+    const char * display_style = "DISPLAY - CIE-XYZ-D65_to_REC.1886-REC.709";
+    const char * view_style = "ACES-OUTPUT - ACES2065-1_to_CIE-XYZ-D65 - SDR-100nit-REC709_2.0";
+    const bool do_roundtrip = true;
+    auto group = BuildDisplayViewTransform(display_style, view_style, do_roundtrip);
+
+    // The test harness gets a processor from the transform with the default optimization
+    // level. However, the forward/inverse does not optimize out due to the clamp to AP1
+    // in-between the FixedFunctions.
+    test.setProcessor(group);
+
+    // Set up a grid of RGBA custom values.
+    const int lut_size = 17;
+    OCIOGPUTest::CustomValues values;
+    GenerateIdentityLut3D(values, lut_size, 1.0f);
+    test.setCustomValues(values);
+
+    test.setErrorThreshold(0.004f);
+}
+
+OCIO_ADD_GPU_TEST(FixedFunction, style_aces2_rec709_inv)
+{
+    const char * display_style = "DISPLAY - CIE-XYZ-D65_to_REC.1886-REC.709";
+    const char * view_style = "ACES-OUTPUT - ACES2065-1_to_CIE-XYZ-D65 - SDR-100nit-REC709_2.0";
+    const bool do_roundtrip = false;
+    auto group = BuildDisplayViewTransform(display_style, view_style, do_roundtrip);
+    test.setProcessor(group);
+
+    const int lut_size = 17;
+    OCIOGPUTest::CustomValues values;
+    GenerateIdentityLut3D(values, lut_size, 1.0f);
+    test.setCustomValues(values);
+
+    test.setRelativeComparison(true);
+    test.setExpectedMinimalValue(1.f);
+    test.setErrorThreshold(0.001f);
+}
+
+OCIO_ADD_GPU_TEST(FixedFunction, style_aces2_displayp3_rndtrip)
+{
+    const char * display_style = "DISPLAY - CIE-XYZ-D65_to_DisplayP3";
+    const char * view_style = "ACES-OUTPUT - ACES2065-1_to_CIE-XYZ-D65 - SDR-100nit-P3-D65_2.0";
+    const bool do_roundtrip = true;
+    auto group = BuildDisplayViewTransform(display_style, view_style, do_roundtrip);
+    test.setProcessor(group);
+
+    const int lut_size = 17;
+    OCIOGPUTest::CustomValues values;
+    const float lum_scale = 1.0f;
+    GenerateIdentityLut3D(values, lut_size, lum_scale);
+    test.setCustomValues(values);
+
+    test.setErrorThreshold(0.001f);
+}
+
+OCIO_ADD_GPU_TEST(FixedFunction, style_aces2_displayp3_inv)
+{
+    const char * display_style = "DISPLAY - CIE-XYZ-D65_to_DisplayP3";
+    const char * view_style = "ACES-OUTPUT - ACES2065-1_to_CIE-XYZ-D65 - SDR-100nit-P3-D65_2.0";
+    const bool do_roundtrip = false;
+    auto group = BuildDisplayViewTransform(display_style, view_style, do_roundtrip);
+    test.setProcessor(group);
+
+    const int lut_size = 17;
+    OCIOGPUTest::CustomValues values;
+    const float lum_scale = 1.0f;
+    GenerateIdentityLut3D(values, lut_size, lum_scale);
+    test.setCustomValues(values);
+
+    test.setRelativeComparison(true);
+    test.setExpectedMinimalValue(1.f);
+    test.setErrorThreshold(0.001f);
+}
+
+OCIO_ADD_GPU_TEST(FixedFunction, style_aces2_1000nit_p3_rndtrip)
+{
+    const char * display_style = "DISPLAY - CIE-XYZ-D65_to_ST2084-P3-D65";
+    const char * view_style = "ACES-OUTPUT - ACES2065-1_to_CIE-XYZ-D65 - HDR-1000nit-P3-D65_2.0";
+    const bool do_roundtrip = true;
+    auto group = BuildDisplayViewTransform(display_style, view_style, do_roundtrip);
+    test.setProcessor(group);
+
+    const int lut_size = 17;
+    OCIOGPUTest::CustomValues values;
+    const float lum_scale = 0.75183f;  // scale to 1000 nits
+    GenerateIdentityLut3D(values, lut_size, lum_scale);
+    test.setCustomValues(values);
+
+    // TODO: Investigate why this is not closer.
+    // Setting the CPUProcessor to OPTIMIZATION_NONE helps slightly, but is not the main
+    // cause of the error.
+    test.setErrorThreshold(0.012f);
+}
+
+OCIO_ADD_GPU_TEST(FixedFunction, style_aces2_1000nit_p3_inv)
+{
+    const char * display_style = "DISPLAY - CIE-XYZ-D65_to_ST2084-P3-D65";
+    const char * view_style = "ACES-OUTPUT - ACES2065-1_to_CIE-XYZ-D65 - HDR-1000nit-P3-D65_2.0";
+    const bool do_roundtrip = false;
+    auto group = BuildDisplayViewTransform(display_style, view_style, do_roundtrip);
+    test.setProcessor(group);
+
+    const int lut_size = 17;
+    OCIOGPUTest::CustomValues values;
+    const float lum_scale = 0.75183f;  // scale to 1000 nits
+    GenerateIdentityLut3D(values, lut_size, lum_scale);
+    test.setCustomValues(values);
+
+    test.setRelativeComparison(true);
+    test.setExpectedMinimalValue(1.f);
+    test.setErrorThreshold(0.001f);
+}
+
+OCIO_ADD_GPU_TEST(FixedFunction, style_aces2_4000nit_p3_rndtrip)
+{
+    const char * display_style = "DISPLAY - CIE-XYZ-D65_to_ST2084-P3-D65";
+    const char * view_style = "ACES-OUTPUT - ACES2065-1_to_CIE-XYZ-D65 - HDR-4000nit-P3-D65_2.0";
+    const bool do_roundtrip = true;
+    auto group = BuildDisplayViewTransform(display_style, view_style, do_roundtrip);
+    test.setProcessor(group);
+
+    const int lut_size = 17;
+    OCIOGPUTest::CustomValues values;
+    const float lum_scale = 0.90257f;  // scale to 4000 nits
+    GenerateIdentityLut3D(values, lut_size, lum_scale);
+    test.setCustomValues(values);
+
+    // TODO: Investigate why this is not closer.
+    test.setErrorThreshold(0.018f);
+}
+
+OCIO_ADD_GPU_TEST(FixedFunction, style_aces2_4000nit_p3_inv)
+{
+    const char * display_style = "DISPLAY - CIE-XYZ-D65_to_ST2084-P3-D65";
+    const char * view_style = "ACES-OUTPUT - ACES2065-1_to_CIE-XYZ-D65 - HDR-4000nit-P3-D65_2.0";
+    const bool do_roundtrip = false;
+    auto group = BuildDisplayViewTransform(display_style, view_style, do_roundtrip);
+    test.setProcessor(group);
+
+    const int lut_size = 17;
+    OCIOGPUTest::CustomValues values;
+    const float lum_scale = 0.90257f;  // scale to 4000 nits
+    GenerateIdentityLut3D(values, lut_size, lum_scale);
+    test.setCustomValues(values);
+
+    test.setRelativeComparison(true);
+    test.setExpectedMinimalValue(1.f);
+    test.setErrorThreshold(0.001f);
+}
+
+OCIO_ADD_GPU_TEST(FixedFunction, style_aces2_4000nit_rec2020_rndtrip)
+{
+    const char * display_style = "DISPLAY - CIE-XYZ-D65_to_REC.2100-PQ";
+    const char * view_style = "ACES-OUTPUT - ACES2065-1_to_CIE-XYZ-D65 - HDR-4000nit-REC2020_2.0";
+    const bool do_roundtrip = true;
+    auto group = BuildDisplayViewTransform(display_style, view_style, do_roundtrip);
+    test.setProcessor(group);
+
+    const int lut_size = 17;
+    OCIOGPUTest::CustomValues values;
+    const float lum_scale = 0.90257f;  // scale to 4000 nits
+    GenerateIdentityLut3D(values, lut_size, lum_scale);
+    test.setCustomValues(values);
+
+    // TODO: Investigate why this is not closer.
+    test.setErrorThreshold(0.03f);
+}
+
+OCIO_ADD_GPU_TEST(FixedFunction, style_aces2_4000nit_rec2020_inv)
+{
+    const char * display_style = "DISPLAY - CIE-XYZ-D65_to_REC.2100-PQ";
+    const char * view_style = "ACES-OUTPUT - ACES2065-1_to_CIE-XYZ-D65 - HDR-4000nit-REC2020_2.0";
+    const bool do_roundtrip = false;
+    auto group = BuildDisplayViewTransform(display_style, view_style, do_roundtrip);
+    test.setProcessor(group);
+
+    const int lut_size = 17;
+    OCIOGPUTest::CustomValues values;
+    const float lum_scale = 0.90257f;  // scale to 4000 nits
+    GenerateIdentityLut3D(values, lut_size, lum_scale);
+    test.setCustomValues(values);
+
+    test.setRelativeComparison(true);
+    test.setExpectedMinimalValue(1.f);
+    test.setErrorThreshold(0.001f);
+}
+
+OCIO_ADD_GPU_TEST(FixedFunction, style_aces2_d60_4000nit_p3_rndtrip)
+{
+    const char* display_style = "DISPLAY - CIE-XYZ-D65_to_ST2084-P3-D65";
+    const char* view_style = "ACES-OUTPUT - ACES2065-1_to_CIE-XYZ-D65 - HDR-4000nit-P3-D60-in-P3-D65_2.0";
+    const bool do_roundtrip = true;
+    auto group = BuildDisplayViewTransform(display_style, view_style, do_roundtrip);
+    test.setProcessor(group);
+
+    const int lut_size = 17;
+    OCIOGPUTest::CustomValues values;
+    const float lum_scale = 0.90257f;  // scale to 4000 nits
+    GenerateIdentityLut3D(values, lut_size, lum_scale);
+    test.setCustomValues(values);
+
+    // TODO: Investigate why this is not closer.
+    test.setErrorThreshold(0.03f);
+}
+
+OCIO_ADD_GPU_TEST(FixedFunction, style_aces2_d60_4000nit_p3_inv)
+{
+    const char* display_style = "DISPLAY - CIE-XYZ-D65_to_ST2084-P3-D65";
+    const char* view_style = "ACES-OUTPUT - ACES2065-1_to_CIE-XYZ-D65 - HDR-4000nit-P3-D60-in-P3-D65_2.0";
+    const bool do_roundtrip = false;
+    auto group = BuildDisplayViewTransform(display_style, view_style, do_roundtrip);
+    test.setProcessor(group);
+
+    const int lut_size = 17;
+    OCIOGPUTest::CustomValues values;
+    const float lum_scale = 0.90257f;  // scale to 4000 nits
+    GenerateIdentityLut3D(values, lut_size, lum_scale);
+    test.setCustomValues(values);
+
+    // Difference is on equal RGB, above about 3600, peaking around 3684, and stopping at 3696
+    test.setRelativeComparison(true);
+    test.setExpectedMinimalValue(1.f);
+    test.setErrorThreshold(0.005f);
+}
+
+OCIO_ADD_GPU_TEST(FixedFunction, style_aces2_nan_bug)
+{
+    const char* display_style = "DISPLAY - CIE-XYZ-D65_to_ST2084-P3-D65";
+    const char* view_style = "ACES-OUTPUT - ACES2065-1_to_CIE-XYZ-D65 - HDR-4000nit-P3-D60-in-P3-D65_2.0";
+    const bool do_roundtrip = false;
+    auto group = BuildDisplayViewTransform(display_style, view_style, do_roundtrip);
+    test.setProcessor(group);
+
+    OCIOGPUTest::CustomValues values;
+    values.m_inputValues =
+    {
+        0.89942779f, 0.89942779f, 0.89942779f, 1.0f,
+        // This second value became NaN on the GPU before the Aab_to_RGB fix.
+        // FIXME: The GPU is no longer NaN, but it is still hugely different from the CPU.
+        // 0.89944305f, 0.89944305f, 0.89944305f, 1.0f
+    };
+    test.setCustomValues(values);
+
+    test.setRelativeComparison(true);
+    test.setExpectedMinimalValue(1.f);
+    test.setErrorThreshold(0.01f);
+}
+
 OCIO_ADD_GPU_TEST(FixedFunction, style_aces2_rgb_to_jmh_fwd)
 {
     // ACES AP0
@@ -862,8 +1175,8 @@ OCIO_ADD_GPU_TEST(FixedFunction, style_RGB_TO_HSV_fwd)
 
     test.setErrorThreshold(1e-6f);
 
-#ifdef __APPLE__
     test.setTestNaN(false);
+#ifdef __APPLE__
     test.setTestInfinity(false);
 #endif
 }
@@ -929,6 +1242,144 @@ OCIO_ADD_GPU_TEST(FixedFunction, style_RGB_TO_HSV_inv_custom)
     test.setErrorThreshold(1e-6f);
 }
 
+OCIO_ADD_GPU_TEST(FixedFunction, style_RGB_TO_HSY_LIN_fwd)
+{
+    OCIO::FixedFunctionTransformRcPtr func =
+        OCIO::FixedFunctionTransform::Create(OCIO::FIXED_FUNCTION_RGB_TO_HSY_LIN);
+    func->setDirection(OCIO::TRANSFORM_DIR_FORWARD);
+
+    test.setProcessor(func);
+
+    OCIOGPUTest::CustomValues values;
+    values.m_inputValues = {
+        -0.075290f,  0.078996f, -0.108397f, 0.f,
+         0.3f,       0.4f,       0.5f,      0.f,
+         0.05f,      0.03f,      0.04f,     0.f,
+         0.01f,      0.01f,     -0.05f,     1.f,
+         0.05f,     -0.005f,    -0.05f,     1.f,
+        -0.048f,     0.01f,      0.05f,     0.f,
+         0.3f,      -0.4f,       0.5f,      0.f,
+        -0.055f,     0.01f,      0.05f,     0.f };
+    test.setCustomValues(values);
+
+    test.setErrorThreshold(5e-6f);
+}
+
+OCIO_ADD_GPU_TEST(FixedFunction, style_RGB_TO_HSY_LIN_inv)
+{
+    OCIO::FixedFunctionTransformRcPtr func =
+        OCIO::FixedFunctionTransform::Create(OCIO::FIXED_FUNCTION_RGB_TO_HSY_LIN);
+    func->setDirection(OCIO::TRANSFORM_DIR_INVERSE);
+
+    test.setProcessor(func);
+
+    OCIOGPUTest::CustomValues values;
+    values.m_inputValues = {
+         0.470554752f,    9.12594033f,   0.0326650218f,  0.f,   // hsy alpha == 1
+         0.75f,           0.22196741f,   0.38596f,       0.f,
+         0.08333333f,     0.12976444f,   0.034974f,      0.f,
+         0.333333333333f, 0.606036032f,  0.0056680f,     1.f,   // hsy mid alpha
+         0.241666666667f, 0.8372990325f, 0.0034440f,     1.f,
+         0.734693877551f, 0.752099600f,  0.0005572f,     0.f,   // hsy alpha == 0
+         0.96296296f,     9.7034f,      -0.1862f,        0.f,
+         0.730158730159f, 0.811517000f, -0.0009310f,     0.f };
+    test.setCustomValues(values);
+
+    test.setErrorThreshold(5e-6f);
+}
+
+OCIO_ADD_GPU_TEST(FixedFunction, style_RGB_TO_HSY_LOG_fwd)
+{
+    OCIO::FixedFunctionTransformRcPtr func =
+        OCIO::FixedFunctionTransform::Create(OCIO::FIXED_FUNCTION_RGB_TO_HSY_LOG);
+    func->setDirection(OCIO::TRANSFORM_DIR_FORWARD);
+
+    test.setProcessor(func);
+
+    OCIOGPUTest::CustomValues values;
+    values.m_inputValues = {
+        -0.075290f,  0.078996f, -0.108397f, 0.f,
+         0.3f,       0.4f,       0.5f,      0.f,
+         0.05f,      0.03f,      0.04f,     0.f,
+         0.01f,      0.01f,     -0.05f,     1.f,
+         0.05f,     -0.005f,    -0.05f,     1.f,
+        -0.048f,     0.01f,      0.05f,     0.f,
+         0.3f,      -0.4f,       0.5f,      0.f,
+        -0.055f,     0.01f,      0.05f,     0.f };
+    test.setCustomValues(values);
+
+    test.setErrorThreshold(1e-6f);
+}
+
+OCIO_ADD_GPU_TEST(FixedFunction, style_RGB_TO_HSY_LOG_inv)
+{
+    OCIO::FixedFunctionTransformRcPtr func =
+        OCIO::FixedFunctionTransform::Create(OCIO::FIXED_FUNCTION_RGB_TO_HSY_LOG);
+    func->setDirection(OCIO::TRANSFORM_DIR_INVERSE);
+
+    test.setProcessor(func);
+
+    OCIOGPUTest::CustomValues values;
+    values.m_inputValues = {
+         0.470554752f,    9.12594033f,   0.0326650218f,  0.f,   // hsy alpha == 1
+         0.75f,           0.22196741f,   0.38596f,       0.f,
+         0.08333333f,     0.12976444f,   0.034974f,      0.f,
+         0.333333333333f, 0.606036032f,  0.0056680f,     1.f,   // hsy mid alpha
+         0.241666666667f, 0.8372990325f, 0.0034440f,     1.f,
+         0.734693877551f, 0.752099600f,  0.0005572f,     0.f,   // hsy alpha == 0
+         0.96296296f,     9.7034f,      -0.1862f,        0.f,
+         0.730158730159f, 0.811517000f, -0.0009310f,     0.f };
+    test.setCustomValues(values);
+
+    test.setErrorThreshold(1e-6f);
+}
+
+OCIO_ADD_GPU_TEST(FixedFunction, style_RGB_TO_HSY_VID_fwd)
+{
+    OCIO::FixedFunctionTransformRcPtr func =
+        OCIO::FixedFunctionTransform::Create(OCIO::FIXED_FUNCTION_RGB_TO_HSY_VID);
+    func->setDirection(OCIO::TRANSFORM_DIR_FORWARD);
+
+    test.setProcessor(func);
+
+    OCIOGPUTest::CustomValues values;
+    values.m_inputValues = {
+        -0.075290f,  0.078996f, -0.108397f, 0.f,
+         0.3f,       0.4f,       0.5f,      0.f,
+         0.05f,      0.03f,      0.04f,     0.f,
+         0.01f,      0.01f,     -0.05f,     1.f,
+         0.05f,     -0.005f,    -0.05f,     1.f,
+        -0.048f,     0.01f,      0.05f,     0.f,
+         0.3f,      -0.4f,       0.5f,      0.f,
+        -0.055f,     0.01f,      0.05f,     0.f };
+    test.setCustomValues(values);
+
+    test.setErrorThreshold(1e-6f);
+}
+
+OCIO_ADD_GPU_TEST(FixedFunction, style_RGB_TO_HSY_VID_inv)
+{
+    OCIO::FixedFunctionTransformRcPtr func =
+        OCIO::FixedFunctionTransform::Create(OCIO::FIXED_FUNCTION_RGB_TO_HSY_VID);
+    func->setDirection(OCIO::TRANSFORM_DIR_INVERSE);
+
+    test.setProcessor(func);
+
+    OCIOGPUTest::CustomValues values;
+    values.m_inputValues = {
+         0.470554752f,    9.12594033f,   0.0326650218f,  0.f,   // hsy alpha == 1
+         0.75f,           0.22196741f,   0.38596f,       0.f,
+         0.08333333f,     0.12976444f,   0.034974f,      0.f,
+         0.333333333333f, 0.606036032f,  0.0056680f,     1.f,   // hsy mid alpha
+         0.241666666667f, 0.8372990325f, 0.0034440f,     1.f,
+         0.734693877551f, 0.752099600f,  0.0005572f,     0.f,   // hsy alpha == 0
+         0.96296296f,     9.7034f,      -0.1862f,        0.f,
+         0.730158730159f, 0.811517000f, -0.0009310f,     0.f };
+    test.setCustomValues(values);
+
+    test.setErrorThreshold(1e-6f);
+}
+
 OCIO_ADD_GPU_TEST(FixedFunction, style_XYZ_TO_xyY_fwd)
 {
     OCIO::FixedFunctionTransformRcPtr func =
@@ -981,7 +1432,8 @@ OCIO_ADD_GPU_TEST(FixedFunction, style_XYZ_TO_LUV_fwd)
 
     test.setProcessor(func);
 
-    test.setErrorThreshold(1e-5f);
+    test.setTestInfinity(false);
+    test.setErrorThreshold(5e-5f);
 }
 
 OCIO_ADD_GPU_TEST(FixedFunction, style_XYZ_TO_LUV_inv)
@@ -992,6 +1444,7 @@ OCIO_ADD_GPU_TEST(FixedFunction, style_XYZ_TO_LUV_inv)
 
     test.setProcessor(func);
 
+    test.setTestInfinity(false);
     test.setErrorThreshold(1e-5f);
 }
 
@@ -1003,6 +1456,9 @@ OCIO_ADD_GPU_TEST(FixedFunction, style_LIN_TO_PQ_fwd)
     test.setWideRangeInterval(-0.1f, 100.1f);
     test.setProcessor(func);
 
+    test.setTestInfinity(false);
+    test.setTestNaN(false);
+
     // Using large threshold for SSE2 as that will enable usage of fast but
     // approximate power function ssePower.
     test.setErrorThreshold(OCIO_USE_SSE2 ? 0.0008f : 2e-5f);
@@ -1025,6 +1481,8 @@ OCIO_ADD_GPU_TEST(FixedFunction, style_LIN_TO_PQ_inv)
     test.setProcessor(func);
     test.setRelativeComparison(true); // Since the output range will be 0..100, we set the relative epsilon.
     test.setErrorThreshold(OCIO_USE_SSE2 ? 0.0023f : 1.5e-4f);
+    test.setTestInfinity(false);
+    test.setTestNaN(false);
 }
 
 namespace
@@ -1060,6 +1518,8 @@ OCIO_ADD_GPU_TEST(FixedFunction, style_LIN_TO_GAMMA_LOG_fwd)
     test.setWideRangeInterval(-0.1f, 3.35f); // Output ~[-0.3, 1.02]
     test.setProcessor(func);
     test.setErrorThreshold(1e-6f);
+    test.setTestInfinity(false);
+    test.setTestNaN(false);
 }
 
 OCIO_ADD_GPU_TEST(FixedFunction, style_LIN_TO_GAMMA_LOG_inv)
@@ -1070,6 +1530,7 @@ OCIO_ADD_GPU_TEST(FixedFunction, style_LIN_TO_GAMMA_LOG_inv)
     test.setWideRangeInterval(-0.3f, 1.02f); // Output ~[-0.1, 3.35]
     test.setProcessor(func);
     test.setErrorThreshold(1e-6f);
+    test.setTestInfinity(false);
 }
 
 OCIO_ADD_GPU_TEST(FixedFunction, style_LIN_TO_DOUBLE_LOG_fwd)
@@ -1090,6 +1551,8 @@ OCIO_ADD_GPU_TEST(FixedFunction, style_LIN_TO_DOUBLE_LOG_fwd)
     test.setWideRangeInterval(-1.0f, 2.0f); // Output ~[-1.08, 1.4]
     test.setProcessor(func);
     test.setErrorThreshold(1e-6f);
+    test.setTestInfinity(false);
+    test.setTestNaN(false);
 }
 
 OCIO_ADD_GPU_TEST(FixedFunction, style_LIN_TO_DOUBLE_LOG_inv)
@@ -1110,4 +1573,5 @@ OCIO_ADD_GPU_TEST(FixedFunction, style_LIN_TO_DOUBLE_LOG_inv)
     test.setWideRangeInterval(-1.1f, 1.4f); // Output ~[-1.0, 2.0]
     test.setProcessor(func);
     test.setErrorThreshold(1e-6f);
+    test.setTestInfinity(false);
 }
